library(dplyr)
library(tidyr)
library(stringr)
library(ggplot2)

data.raw<-read.table("data/slx11114_multiplex_optimisation.csv",header=T,sep=",",stringsAsFactors = F,row=1)

read_number<-1000
microsatellite_min = 20
microsatellite_max = 40

# re-arrange data for use with tidyr, dplyr and ggplot
data.edit = data.frame(t(data.raw)) 
sample.names = row.names(data.edit)
data.edit = cbind(data.edit,sample.names)

data.final = data.edit %>%
  separate(sample.names, into = c("loci", "num", "direction", "Dinuc", "Crypt"), sep = "_") %>%
  mutate(Loci_full = paste(loci, num, sep = '_')) %>%
  gather(Tract_Length, NumReads, 1:51) %>%
  mutate(NumReads, NumReads = as.numeric(NumReads)) %>%
  mutate(Tract_Length = str_replace(Tract_Length, "X", "")) %>%
  mutate(Tract_Length = as.numeric(Tract_Length)) %>%
  mutate(dist_reads = as.numeric(as.character(dist_reads))) %>%
  mutate(sample_number = as.numeric(as.character(sample_number))) %>%
  filter(Tract_Length >= microsatellite_min, Tract_Length <= microsatellite_max) %>%
  within(dist_reads<-ave(NumReads, sample_number, direction, Loci_full, FUN=sum)) %>%
  select(total_reads,sample_number,multiplex_group,dist_reads,direction,Crypt,Loci_full,Tract_Length,NumReads,pct_WT)                   

data.final = transform(data.final, propReads = NumReads / dist_reads)

is.nan.data.frame <- function(x)
  do.call(cbind, lapply(x, is.nan))

data.final[is.nan(data.final)] <- 0


#### pick out WT distributions #####
data.plot = filter(data.final, pct_WT == 100) %>%
            # locus sX_1395 is a heterozygous locus in this template
            filter(Loci_full != "sX_1395") %>%
            # select [CA]23 to [CA]35 for display purposes
            filter(Tract_Length > 23 & Tract_Length < 35)
theme_set(theme_gray())

# plot figure 1C
pp = ggplot(data.plot, aes(x=Tract_Length,y=propReads,color = as.character(sample_number))) + 
      geom_point(alpha=0.8, size=3) + geom_line(alpha=0.2, size=1.5) +
      facet_wrap( ~ Loci_full, nrow=2,ncol=7) +
      xlab("Repeat length") + ylab("Proportion of reads") +
      theme(legend.text=element_text(size=24),legend.title=element_text(size=28),
        axis.title.x = element_text(size=28), axis.title.y = element_text(size=28),
        strip.text.x = element_text(size=18), strip.text.y = element_text(size=24),
        axis.text.x = element_text(size=10), axis.text.y = element_text(size=24)) +
      scale_color_discrete(name = "Technical\nreplicates",labels = c("Replicate 1","Replicate 2","Replicate 3","Replicate 4","Replicate 5","Replicate 6","Replicate 7","Replicate 8"))
plot(pp)


#plot locus 1365 only (figure 1D)
## with replicates
plot1365 = data.plot %>% filter(Loci_full == "a4_1365")
pp2 = ggplot(plot1365, aes(x=Tract_Length,y=propReads,color = as.character(sample_number))) + 
  geom_point(alpha=1, size=5) + geom_line(alpha=1, size=2) +
  facet_grid( ~ Loci_full) +
  xlab("Repeat length") + ylab("Proportion of reads") +
  ylim(0,0.35) +
  theme(legend.text=element_text(size=24),legend.title=element_text(size=28),
        axis.title.x = element_text(size=28), axis.title.y = element_text(size=28),
        strip.text.x = element_text(size=24), strip.text.y = element_text(size=24),
        axis.text.x = element_text(size=24), axis.text.y = element_text(size=24)) +
  scale_color_discrete(name = "Technical replicates",labels = c("Replicate 1","Replicate 2","Replicate 3","Replicate 4","Replicate 5","Replicate 6","Replicate 7","Replicate 8"))
plot(pp2)