library(dplyr)
library(tidyr)
library(stringr)
library(ggplot2)
# user defined variables
read_number<-1000
microsatellite_min = 20
microsatellite_max = 40

#read in data
data.raw = read.table("data/slx7545_optimisation_experiments.csv",header=T,sep=",",stringsAsFactors = F,row=1)

# re-format crypt data
data.edit = data.frame(t(data.raw)) 
sample.names = row.names(data.edit)
data.edit = cbind(data.edit,sample.names)

data.final = data.edit %>%
  separate(sample.names, into = c("strand", "num", "direction", "Dinuc","Dinuc2"), sep = "_") %>%
  separate(sample_name, into = c("sample","template","primer")) %>%
  gather(Tract_Length, NumReads, 1:51) %>%
  mutate(NumReads, NumReads = as.numeric(NumReads)) %>%
  mutate(Tract_Length = str_replace(Tract_Length, "X", "")) %>%
  mutate(Tract_Length = as.numeric(Tract_Length)) %>%
  mutate(template = str_replace(template, "T", "")) %>%
  mutate(template = as.numeric(as.character(template))) %>%
  mutate(primer = paste(strand,num,sep="_")) %>%
  filter(Tract_Length >= microsatellite_min, Tract_Length <= microsatellite_max) %>%
  within(dist_reads<-ave(NumReads, sample_number, direction, primer, FUN=sum)) %>%
  select(total_reads, sample_number, primer, direction,Tract_Length, NumReads,dist_reads,template) 

### calculare proportional read values
data.final = transform(data.final, propReads = NumReads / dist_reads)

is.nan.data.frame <- function(x)
  do.call(cbind, lapply(x, is.nan))

data.final[is.nan(data.final)] <- 0

# plot figure 1E
plot.df = data.final %>%
  filter(dist_reads > 1000) %>%
  filter(primer == "a4_1365")

pp = ggplot(plot.df, aes(x=Tract_Length,y=propReads,color=as.character(template))) + 
  geom_point(alpha=1, size=5) +
  geom_line(alpha=1, size=2) +
  facet_grid( ~ primer) +
  xlab("Repeat length") + ylab("Proportion of reads") +
  theme(legend.text=element_text(size=24),legend.title=element_text(size=28),
        axis.title.x = element_text(size=28), axis.title.y = element_text(size=28),
        strip.text.x = element_text(size=24), strip.text.y = element_text(size=24),
        axis.text.x = element_text(size=24), axis.text.y = element_text(size=24)) +
  scale_color_discrete(name = "Mouse",labels = c("Mouse 1","Mouse 2", "Mouse 3", "Mouse 4", "Mouse 5", "Mouse 6"))
plot(pp)


