library(dplyr)
library(tidyr)
library(stringr)
library(ggplot2)
# user defined variables
read_number<-1000
microsatellite_min = 20
microsatellite_max = 40

# merge to form raw data for crypt
data.crypt.raw = read.table("data/slx7547_optimisation_crypt_seq.csv",header=T,sep=",",stringsAsFactors = F,row=1)
data.mock.raw = read.table("data/slx7545_optimisation_experiments.csv",header=T,sep=",",stringsAsFactors = F,row=1)

#######################################

#re-format each table separately
# re-format crypt data
data.crypt.edit = data.frame(t(data.crypt.raw)) 
sample.names = row.names(data.crypt.edit)
data.crypt.edit = cbind(data.crypt.edit,sample.names)

data.crypt.final = data.crypt.edit %>%
  separate(sample.names, into = c("chrom", "num", "direction", "Dinuc","Dinuc2"), sep = "_") %>%
  gather(Tract_Length, NumReads, 1:51) %>%
  mutate(NumReads, NumReads = as.numeric(NumReads)) %>%
  mutate(Tract_Length = str_replace(Tract_Length, "X", "")) %>%
  mutate(Tract_Length = as.numeric(Tract_Length)) %>%
  mutate(sample_number = as.numeric(as.character(sample_number))) %>%
  mutate(primer = paste(chrom,num,sep="_")) %>%
  mutate(primer = as.character(primer)) %>%
  filter(Tract_Length >= microsatellite_min, Tract_Length <= microsatellite_max) %>%
  within(dist_reads<-ave(NumReads, sample_number, primer, FUN=sum)) %>%
  select(total_reads, sample_number, primer, direction,Tract_Length, NumReads,dist_reads) 

crypt.col = data.frame(rep("crypt",nrow(data.crypt.final)))
colnames(crypt.col) = "type"
data.crypt.final = cbind(data.crypt.final,crypt.col)

########################
# re-format mock data
data.mock.edit = data.frame(t(data.mock.raw)) 
sample.names = row.names(data.mock.edit)
data.mock.edit = cbind(data.mock.edit,sample.names)

data.mock.final = data.mock.edit %>%
  separate(sample.names, into = c("chrom", "num", "direction", "Dinuc","Dinuc2"), sep = "_") %>%
  separate(sample_name, into = c("sample", "template", "primer_num"), sep = "_") %>%
  gather(Tract_Length, NumReads, 1:51) %>%
  mutate(NumReads, NumReads = as.numeric(NumReads)) %>%
  mutate(Tract_Length = str_replace(Tract_Length, "X", "")) %>%
  mutate(Tract_Length = as.numeric(Tract_Length)) %>%
  mutate(template = str_replace(template, "T", "")) %>%
  mutate(template = as.numeric(as.character(template))) %>%
  mutate(primer = paste(chrom,num,sep="_")) %>%
  mutate(sample_number = str_replace(sample_number, "S", "")) %>%
  mutate(sample_number = as.numeric(as.character(sample_number))) %>%
  filter(Tract_Length >= microsatellite_min, Tract_Length <= microsatellite_max) %>%
  within(dist_reads<-ave(NumReads, sample_number, primer, FUN=sum)) %>%
  filter(template == 6) %>%
  select(total_reads, sample_number, primer, direction,Tract_Length, NumReads,dist_reads) 

mock.col = data.frame(rep("mock",nrow(data.mock.final)))
colnames(mock.col) = "type"
data.mock.final = cbind(data.mock.final,mock.col)

# merge two tables
data.final = rbind(data.crypt.final,data.mock.final)

### calculare proportional read values
data.final = transform(data.final, propReads = NumReads / dist_reads)

is.nan.data.frame <- function(x)
  do.call(cbind, lapply(x, is.nan))

data.final[is.nan(data.final)] <- 0

### compare mock and real crypts read distribution
loci_rep = c("a2_5196","a4_1365")
plot.df = subset(data.final, primer %in% loci_rep) %>%
          filter(dist_reads > read_number & sample_number > 331)

### plot figure 1F
pp = ggplot(plot.df, aes(x=Tract_Length,y=propReads,color = as.character(type))) + 
  geom_point(alpha=1, size=5) +
  geom_line(alpha=1, size=2) +
  facet_grid( ~ primer) +
  xlab("Repeat length") + ylab("Proportion of reads") +
  theme(legend.text=element_text(size=24),legend.title=element_text(size=28),
        axis.title.x = element_text(size=28), axis.title.y = element_text(size=28),
        strip.text.x = element_text(size=24), strip.text.y = element_text(size=24),
        axis.text.x = element_text(size=24), axis.text.y = element_text(size=24)) +
  scale_color_discrete(name = "Sample type",labels = c("Crypt","Crypt equivalent"))

plot(pp)
