library(dplyr)
library(tidyr)
library(stringr)
library(ggplot2)
library(plyr)
library(scales)
# user defined variables
read_number<-1000
microsatellite_min = 20
microsatellite_max = 40

source("src/least_square_function3.0.R")
# read in data for samples to be compared

# table 1 - mouse
data.raw.mouse<-read.table("data/SLX10934_plasmid_mouseeq.csv",header=T,sep=",",stringsAsFactors = F,row=1)
# table 2
data.raw.hi<-read.table("data/slx10937_plasmid_high.csv",header=T,sep=",",stringsAsFactors = F,row=1)

# re-format each dataset separately
# this has to be done separately as duplicate rownames causes issues

#table 1 re-format
data.edit = data.frame(t(data.raw.mouse)) 
sample.names = row.names(data.edit)
data.edit = cbind(data.edit,sample.names)

data.final.mouse = data.edit %>%
  separate(sample.names, into = c("loci", "num", "direction", "Dinuc", "Crypt"), sep = "_") %>%
  mutate(Loci_full = paste(loci, num, sep = '_')) %>%
  separate(sample_name, into = c("sample","locus","wt_length","mutant_length","wt","rep"),sep="_") %>%
  mutate(mutant_length = as.character(mutant_length)) %>%
  gather(Tract_Length, NumReads, 1:51) %>%
  mutate(NumReads, NumReads = as.numeric(NumReads)) %>%
  mutate(Tract_Length = str_replace(Tract_Length, "X", "")) %>%
  mutate(Tract_Length = as.numeric(Tract_Length)) %>%
  mutate(dist_reads = as.numeric(as.character(dist_reads))) %>%
  mutate(sample_number = as.numeric(as.character(sample_number))) %>%
  mutate(type = "mouse") %>%
  filter(Tract_Length >= microsatellite_min, Tract_Length <= microsatellite_max) %>%
  select(total_reads,sample_number,multiplex_group,dist_reads,direction,Crypt,Loci_full,Tract_Length,NumReads,pct_WT,slxID,mutant_length,type) 

#table 2 re-format
data.edit = data.frame(t(data.raw.hi)) 
sample.names = row.names(data.edit)
data.edit = cbind(data.edit,sample.names)

data.final.hi = data.edit %>%
  separate(sample.names, into = c("loci", "num", "direction", "Dinuc", "Crypt"), sep = "_") %>%
  mutate(Loci_full = paste(loci, num, sep = '_')) %>%
  separate(sample_name, into = c("sample","type2","locus","wt_length","mutant_length","wt","rep"),sep="_") %>%
  mutate(mutant_length = as.character(mutant_length)) %>%
  gather(Tract_Length, NumReads, 1:51) %>%
  mutate(NumReads, NumReads = as.numeric(NumReads)) %>%
  mutate(Tract_Length = str_replace(Tract_Length, "X", "")) %>%
  mutate(Tract_Length = as.numeric(Tract_Length)) %>%
  mutate(dist_reads = as.numeric(as.character(dist_reads))) %>%
  mutate(sample_number = as.numeric(as.character(sample_number))) %>%
  mutate(type = "high") %>%
  filter(Tract_Length >= microsatellite_min, Tract_Length <= microsatellite_max) %>%
  select(total_reads,sample_number,multiplex_group,dist_reads,direction,Crypt,Loci_full,Tract_Length,NumReads,pct_WT,slxID,mutant_length,type)

### gather all data together here
data.final = rbind(data.final.mouse,data.final.hi) %>%
              mutate(type = as.character(type))

### calculare proportional read values
data.final = transform(data.final, propReads = NumReads / dist_reads)

is.nan.data.frame <- function(x)
  do.call(cbind, lapply(x, is.nan))

data.final[is.nan(data.final)] <- 0

# calculate phi value for each sample
# ensure correct reference distribution is used for each

# determine different loci
loci_all = unique(data.final$Loci_full)
type_all = unique(data.final$type)

all.phi = c()
all.shift = c()
all.number = c()
all.loci = c()
all.reads = c()
all.slx = c()
all.pctwt = c()
all.type = c()
all.mutant = c()

# calculate libraries separately
for(lib in type_all) {
  
  #iterate through different loci in dataset
  for (loci in loci_all) {
    
    data.select = filter(data.final, Loci_full == loci & type == lib)
    
    #### create ref dataframe
    data.ref = filter(data.select, pct_WT == 100)
    
    ### calculate median and mean values for each Tract_Length in reference 
    data.ref = within(data.ref, median<-ave(propReads, Tract_Length, FUN=median))
    
    ### create ref.vec
    ref.vec = c()
    
    for (i in 1:length(unique(data.ref$Tract_Length))) {
      
      length = unique(data.ref$Tract_Length)[i]
      test.df = filter(data.ref, Tract_Length == length)
      ref.vec = c(ref.vec,test.df$median[1])
      
    }
    #create vector that is going to contain phi values
    phi.vec = c()
    #create vector that is going to contain shift values
    shift.vec = c()
    
    #determine sample numbers in this subset
    sample_number = unique(data.select$sample_number)
    
    #iterate through each sample and calculate least square
    for (sample in sample_number){
      
      crypt.df = filter(data.select, sample_number == sample)
      crypt.vec = crypt.df$propReads  
      
      ls.df = least_square(ref.vec,crypt.vec)
      
      phi.value<-as.numeric(unlist(strsplit(rownames(ls.df)[which.min(apply(ls.df,MARGIN=1,min))],"_"))[2])
      shift.value = as.numeric(unlist(strsplit(names(ls.df)[which.min(apply(ls.df,MARGIN=2,min))],"_"))[2])
      
      if (shift.value == 0) {
        phi.value = 0
      }
      
      #add minimum value to ls.vector
      phi.vec = c(phi.vec,phi.value)
      #add minimum value to ls.vector
      shift.vec = c(shift.vec,shift.value)
      #add information to vectors containing information for all data
      all.phi = c(all.phi,phi.value)
      all.shift = c(all.shift,shift.value)
      all.number = c(all.number,sample)
      all.loci = c(all.loci,loci)
      all.reads = c(all.reads,crypt.df$dist_reads[1])
      all.slx = c(all.slx,as.character(crypt.df$slxID[1]))
      all.pctwt = c(all.pctwt,as.numeric(as.character(crypt.df$pct_WT[1])))
      all.type = c(all.type, crypt.df$type[1])
      all.mutant = c(all.mutant, crypt.df$mutant_length[1])
    }
    
  }
  
}

all.data = data.frame(cbind(all.slx, all.number, all.loci, all.phi, all.shift, all.reads, all.pctwt, all.type,all.mutant))
colnames(all.data) = c("slxID","sample","loci","phi","shift","dist_reads","pct_WT","type","mutant_length")

## plot figure 2C (this does not require phi values so can use the pre-processed data)
plot.dist = data.final %>%
  mutate(pct_WT = as.numeric(as.character(pct_WT))) %>%
  filter(pct_WT == 100 | pct_WT == 0) %>%
  filter(type == "mouse") 

#create summary data
plot.dist = ddply(plot.dist, c("Loci_full","Tract_Length","mutant_length","type","pct_WT"), summarise,
                  N    = length(propReads),
                  mean = mean(propReads),
                  sd   = sd(propReads),
                  se   = sd / sqrt(N)
)

#plot only pure populations (no mixtures)
for (i in 1:nrow(plot.dist)) {
  
  if(plot.dist$pct_WT[i] == 100) {
    
    plot.dist$mutant_length[i] = 30
    
  }
  
}


pp = ggplot(plot.dist,aes(x=Tract_Length, y=mean, colour=as.character(mutant_length))) +
  geom_point(alpha=1, size=5) +
  geom_line(alpha=1, size=2) +
  facet_grid(Loci_full ~ .) +
  xlab("[CA] repeat length") + ylab("Proportion of reads") +
  #ylim(0,0.5) +
  theme(legend.text=element_text(size=24),legend.title=element_text(size=28),
        axis.title.x = element_text(size=28), axis.title.y = element_text(size=28),
        strip.text.x = element_text(size=24), strip.text.y = element_text(size=24),
        axis.text.x = element_text(size=24), axis.text.y = element_text(size=24)) +
  scale_color_discrete(name = "Template length",labels=c("[CA]27","[CA]28","[CA]29","[CA]30","[CA]31","[CA]33"))

plot(pp)

### plot figure 2E (this requires phi values)
plot.df = all.data %>%
          mutate(sample = as.numeric(as.character(sample))) %>%
          mutate(dist_reads = as.numeric(as.character(dist_reads))) %>%
          mutate(phi = as.numeric(as.character(phi))) %>%
          mutate(pct_WT = as.numeric(as.character(pct_WT))) %>%
          mutate(mutant_length = paste("[CA]",mutant_length, sep = '')) %>%
          filter(type == "mouse" & dist_reads > read_number)

pp2 = ggplot(plot.df,aes(x=pct_WT, y=phi,color=mutant_length)) + 
  geom_jitter(alpha=0.5, width=5, size=3) +
  facet_grid(loci ~ .) +
  xlab("% wild-type template") + ylab("Phi") +
  #ylim(0,1) +
  geom_abline(intercept=1, slope = -0.01, linetype="dashed", alpha=0.2, size=1.2) +
  theme(legend.text=element_text(size=24),legend.title=element_text(size=28),
        axis.title.x = element_text(size=28), axis.title.y = element_text(size=28),
        strip.text.x = element_text(size=24), strip.text.y = element_text(size=24),
        axis.text.x = element_text(size=24), axis.text.y = element_text(size=24)) +
  scale_color_discrete(name = "Mutant template\nlength",labels=c("[CA]27","[CA]28","[CA]29","[CA]31","[CA]33"))

plot(pp2)


