library(dplyr)
library(tidyr)
library(stringr)
library(ggplot2)
library(plyr)
# user defined variables
read_number<-1000
microsatellite_min = 20
microsatellite_max = 40

source("src/least_square_function3.0.R")

# read in data for samples to be compared
# table 1
data.raw.yfp1<-read.table("data/slx9313_yfp_crypts_unwashed1.csv",header=T,sep=",",stringsAsFactors = F,row=1)
#table 2
data.raw.yfp2<-read.table("data/slx9314_yfp_crypts_unwashed2.csv",header=T,sep=",",stringsAsFactors = F,row=1)
# table 3
data.raw.wash1<-read.table("data/slx10513_yfp_crypts_washed1.csv",header=T,sep=",",stringsAsFactors = F,row=1)
# table 4
data.raw.wash2<-read.table("data/slx10514_yfp_crypts_washed2.csv",header=T,sep=",",stringsAsFactors = F,row=1)

# re-format each dataset separately
# this has to be done separately as duplicate rownames cause problems
# table 1 re-format
data.edit = data.frame(t(data.raw.yfp1)) 
sample.names = row.names(data.edit)
data.edit = cbind(data.edit,sample.names)

data.final.yfp1 = data.edit %>%
  separate(sample.names, into = c("loci", "num", "direction", "Dinuc", "Crypt"), sep = "_") %>%
  mutate(Loci_full = paste(loci, num, sep = '_')) %>%
  separate(sample_name, into = c("sample","status","crypt"),sep="_") %>%
  mutate(status = as.character(status)) %>%
  gather(Tract_Length, NumReads, 1:51) %>%
  mutate(NumReads, NumReads = as.numeric(NumReads)) %>%
  mutate(Tract_Length = str_replace(Tract_Length, "X", "")) %>%
  mutate(Tract_Length = as.numeric(Tract_Length)) %>%
  mutate(dist_reads = as.numeric(as.character(dist_reads))) %>%
  mutate(sample_number = as.numeric(as.character(sample_number))) %>%
  filter(Tract_Length >= microsatellite_min, Tract_Length <= microsatellite_max) %>%
  within(dist_reads<-ave(NumReads, sample_number, direction, Loci_full, FUN=sum)) %>%
  select(dist_reads,direction,Loci_full,Tract_Length,NumReads,pct_WT,slxID,sample_number,status)

#table 2 re-format
data.edit = data.frame(t(data.raw.yfp2)) 
sample.names = row.names(data.edit)
data.edit = cbind(data.edit,sample.names)

data.final.yfp2 = data.edit %>%
  separate(sample.names, into = c("loci", "num", "direction", "Dinuc", "Crypt"), sep = "_") %>%
  mutate(Loci_full = paste(loci, num, sep = '_')) %>%
  separate(sample_name, into = c("sample","status","crypt"),sep="_") %>%
  mutate(status = as.character(status)) %>%
  gather(Tract_Length, NumReads, 1:51) %>%
  mutate(NumReads, NumReads = as.numeric(NumReads)) %>%
  mutate(Tract_Length = str_replace(Tract_Length, "X", "")) %>%
  mutate(Tract_Length = as.numeric(Tract_Length)) %>%
  mutate(dist_reads = as.numeric(as.character(dist_reads))) %>%
  mutate(sample_number = as.numeric(as.character(sample_number))) %>%
  filter(Tract_Length >= microsatellite_min, Tract_Length <= microsatellite_max) %>%
  within(dist_reads<-ave(NumReads, sample_number, direction, Loci_full, FUN=sum)) %>%
  select(dist_reads,direction,Loci_full,Tract_Length,NumReads,pct_WT,slxID,sample_number,status)

#table 3 re-format
data.edit = data.frame(t(data.raw.wash1)) 
sample.names = row.names(data.edit)
data.edit = cbind(data.edit,sample.names)

data.final.wash1 = data.edit %>%
  separate(sample.names, into = c("loci", "num", "direction", "Dinuc", "Crypt"), sep = "_") %>%
  mutate(Loci_full = paste(loci, num, sep = '_')) %>%
  separate(sample_name, into = c("sample","status","crypt"),sep="_") %>%
  mutate(status = as.character(status)) %>%
  gather(Tract_Length, NumReads, 1:51) %>%
  mutate(NumReads, NumReads = as.numeric(NumReads)) %>%
  mutate(Tract_Length = str_replace(Tract_Length, "X", "")) %>%
  mutate(Tract_Length = as.numeric(Tract_Length)) %>%
  mutate(dist_reads = as.numeric(as.character(dist_reads))) %>%
  mutate(sample_number = as.numeric(as.character(sample_number))) %>%
  filter(Tract_Length >= microsatellite_min, Tract_Length <= microsatellite_max) %>%
  within(dist_reads<-ave(NumReads, sample_number, direction, Loci_full, FUN=sum)) %>%
  select(dist_reads,direction,Loci_full,Tract_Length,NumReads,pct_WT,slxID,sample_number,status)

#table 4 re-format
data.edit = data.frame(t(data.raw.wash2)) 
sample.names = row.names(data.edit)
data.edit = cbind(data.edit,sample.names)

data.final.wash2 = data.edit %>%
  separate(sample.names, into = c("loci", "num", "direction", "Dinuc", "Crypt"), sep = "_") %>%
  mutate(Loci_full = paste(loci, num, sep = '_')) %>%
  separate(sample_name, into = c("sample","status","crypt"),sep="_") %>%
  mutate(status = as.character(status)) %>%
  gather(Tract_Length, NumReads, 1:51) %>%
  mutate(NumReads, NumReads = as.numeric(NumReads)) %>%
  mutate(Tract_Length = str_replace(Tract_Length, "X", "")) %>%
  mutate(Tract_Length = as.numeric(Tract_Length)) %>%
  mutate(dist_reads = as.numeric(as.character(dist_reads))) %>%
  mutate(sample_number = as.numeric(as.character(sample_number))) %>%
  filter(Tract_Length >= microsatellite_min, Tract_Length <= microsatellite_max) %>%
  within(dist_reads<-ave(NumReads, sample_number, direction, Loci_full, FUN=sum)) %>%
  select(dist_reads,direction,Loci_full,Tract_Length,NumReads,pct_WT,slxID,sample_number,status) 

### gather all data together here
data.final = rbind(data.final.yfp1, data.final.yfp2, data.final.wash1, data.final.wash2)

### calculare proportional read values
data.final = transform(data.final, propReads = NumReads / dist_reads)

is.nan.data.frame <- function(x)
  do.call(cbind, lapply(x, is.nan))

data.final[is.nan(data.final)] <- 0

# calculate phi value for each sample
# ensure correct reference distribution is used for each

# determine different loci
loci_all = unique(data.final$Loci_full)
slx_all = unique(as.character(data.final$slxID))

all.phi = c()
all.shift = c()
all.loci = c()
all.reads = c()
all.slx = c()
all.pctwt = c()
all.number = c()
all.status = c()
all.prop = t(data.frame(microsatellite_min:microsatellite_max))
colnames(all.prop) = as.character(microsatellite_min:microsatellite_max)

# calculate libraries separately
for(lib in slx_all) {
  
  #iterate through different loci in dataset
  for (loci in loci_all) {
    
    data.select = filter(data.final, Loci_full == loci & slxID == lib)
    
    #### create ref dataframe
    data.ref = filter(data.select, pct_WT == 100 & dist_reads > read_number)
    
    ### calculate median and mean values for each Tract_Length in reference 
    data.ref = within(data.ref, median<-ave(propReads, Tract_Length, FUN=median))
    
    ### create ref.vec
    ref.vec = c()
    
    for (i in 1:length(unique(data.ref$Tract_Length))) {
      
      length = unique(data.ref$Tract_Length)[i]
      test.df = filter(data.ref, Tract_Length == length)
      ref.vec = c(ref.vec,test.df$median[1])
      
    }
    #create vector that is going to contain phi values
    phi.vec = c()
    #create vector that is going to contain shift values
    shift.vec = c()
    
    #determine sample numbers in this subset
    sample_number = unique(data.select$sample_number)
    
    #iterate through each sample and calculate least square
    for (sample in sample_number){
      
      crypt.df = filter(data.select, sample_number == sample)
      crypt.vec = crypt.df$propReads  
      
      ls.df = least_square(ref.vec,crypt.vec)
      ls.df[sapply(ls.df,is.na)] = 0
      
      phi.value<-as.numeric(unlist(strsplit(rownames(ls.df)[which.min(apply(ls.df,MARGIN=1,min))],"_"))[2])
      shift.value = as.numeric(unlist(strsplit(names(ls.df)[which.min(apply(ls.df,MARGIN=2,min))],"_"))[2])
      
      if (shift.value == 0) {
        phi.value = 0
      }
      
      if (phi.value <= 0.1) {
        shift.value = 0
      }
      
      #add minimum value to ls.vector
      phi.vec = c(phi.vec,phi.value)
      #add minimum value to ls.vector
      shift.vec = c(shift.vec,shift.value)
      #add information to vectors containing information for all data
      all.phi = c(all.phi,phi.value)
      all.shift = c(all.shift,shift.value)
      all.loci = c(all.loci,loci)
      all.reads = c(all.reads,crypt.df$dist_reads[1])
      all.slx = c(all.slx,as.character(crypt.df$slxID[1]))
      all.pctwt = c(all.pctwt,as.numeric(as.character(crypt.df$pct_WT[1])))
      all.number = c(all.number,sample)
      all.status = c(all.status,as.character(crypt.df$status[1]))
      all.prop = rbind(all.prop,crypt.df$propReads)

    }
  
  }
    
}

all.data = data.frame(cbind(all.slx, all.loci, all.phi, all.shift, all.reads, all.pctwt,all.number,all.status))
colnames(all.data) = c("slxID","loci","phi","shift","dist_reads","pct_WT","sample","status")

all.prop = all.prop[-1,]
rownames(all.prop) = rownames(all.data)

#write.table(all.data, file="yfp_crypts_summary.csv",row.names=F,sep=",")

########################################
########################################
### plot washed crypts
### figure 3B
plot.df = all.data %>%
  mutate(sample = as.numeric(as.character(sample))) %>%
  mutate(dist_reads = as.numeric(as.character(dist_reads))) %>%
  mutate(phi = as.numeric(as.character(phi))) %>%
  mutate(pct_WT = as.character(pct_WT)) %>%
  mutate(slxID = as.character(slxID)) %>%
  filter(dist_reads > read_number) %>%
  filter(slxID == "SLX10513" | slxID == "SLX10514")

plot.summary = ddply(plot.df, c("sample","status"), summarise,
                      N    = length(phi),
                      mean = mean(phi),
                      sd   = sd(phi),
                      se   = sd / sqrt(N)) %>%
  
  filter(N >= 2)

#### with error bars
pp = ggplot(plot.summary,aes(x=sample, y=mean, colour=status)) + 
  geom_point(alpha=1, size =5) +
  geom_errorbar(aes(ymin=mean-sd, ymax=mean+sd), width=2) +
  xlab("Crypt") + ylab("Phi") +
  theme(legend.text=element_text(size=24),legend.title=element_text(size=28),
        axis.title.x = element_text(size=28), axis.title.y = element_text(size=28),
        strip.text.x = element_text(size=24), strip.text.y = element_text(size=24),
        axis.text.x = element_text(size=24), axis.text.y = element_text(size=24)) +
  scale_color_discrete(name = "Crypt status",labels=c("YFP-","YFP+"))

plot(pp)

########################################
########################################
### plot unwashed crypts
### supplementary figure 3A
plot.df2 = all.data %>%
  mutate(sample = as.numeric(as.character(sample))) %>%
  mutate(dist_reads = as.numeric(as.character(dist_reads))) %>%
  mutate(phi = as.numeric(as.character(phi))) %>%
  mutate(pct_WT = as.character(pct_WT)) %>%
  mutate(slxID = as.character(slxID)) %>%
  filter(dist_reads > read_number) %>%
  filter(slxID == "SLX9313" | slxID == "SLX9314")

plot.summary2 = ddply(plot.df2, c("sample","status"), summarise,
                     N    = length(phi),
                     mean = mean(phi),
                     sd   = sd(phi),
                     se   = sd / sqrt(N)) %>%
  
  filter(N >= 2)

### with error bars
pp2 = ggplot(plot.summary2,aes(x=sample, y=mean, colour=status)) + 
  geom_point(alpha=1, size=5) +
  geom_errorbar(aes(ymin=mean-sd, ymax=mean+sd), width=2) +
  xlab("Crypt") + ylab("Phi") +
  theme(legend.text=element_text(size=24),legend.title=element_text(size=28),
        axis.title.x = element_text(size=28), axis.title.y = element_text(size=28),
        strip.text.x = element_text(size=24), strip.text.y = element_text(size=24),
        axis.text.x = element_text(size=24), axis.text.y = element_text(size=24)) +
  scale_color_discrete(name = "Crypt status",labels=c("YFP-","YFP+"))

plot(pp2)
