library(plyr)
library(reshape2)
library(reshape)
library(dplyr)
library(tidyr)
library(stringr)
library(ggplot2)
library(gridExtra)

read_number = 1000
microsatellite_min = 20
microsatellite_max = 40

### read in raw data 
data.raw = read.table("data/wt_summary_data.csv",sep=",", header=T, stringsAsFactors=F)
data.phi = read.table("data/wt_phi_data.csv", sep=",", header=T,stringsAsFactors=F) %>%
              mutate(specific_ID = paste(slxID,mouse_ID,sep="-")) %>%
              filter(loci != "s1_eyfp")
## info on loci to be excluded
loci.exclude = read.table("loci_to_exclude_wt.csv", sep=",", header=T, stringsAsFactors=F)

data.master = data.raw %>%
              filter(mouse_ID != "neg_control" | slxID == "SLX9311" | Loci_full != "s1_eyfp") %>%
              mutate(specific_ID = paste(slxID,mouse_ID,sep="-"))

# exclude loci that have bimodal distributions
for (i in 1:nrow(loci.exclude)) {
  
  data.master = data.master %>%
    filter(slxID != loci.exclude$slxID[i] | mouse_ID != loci.exclude$mouse_ID[i] |
             Loci_full != loci.exclude$loci[i])
  
}

### identify loci represented in data
loci_all = unique(data.master$Loci_full)

#select reference samples
data.ref = data.master %>%
            filter(pct_WT == 100 & dist_reads > 1000)

#calculate median values at each tract length for each reference set
data.ref = within(data.ref, median1<-ave(propReads, Tract_Length, specific_ID, Loci_full, FUN=median))
data.ref = within(data.ref, median2<-ave(propReads, mouse_age, Tract_Length, Loci_full, FUN=median))
#calculate least squares difference at each tract length
data.ref = data.ref %>%
            mutate(ls_ind = (propReads - median1)^2)

#calculate sum of least squares for each reference set (across all tract lengths)
data.ref = within(data.ref, ls_total<-ave(ls_ind, direction, specific_ID, Loci_full, FUN=sum))
data.ref = within(data.ref, ls_mean<-ave(ls_ind, direction, specific_ID, Loci_full, FUN=mean))

variability_threshold=0.0035

#plot supplementary figure 3b
pp = ggplot(data.ref, aes(x=ls_total)) + 
  stat_ecdf(geom = "step", size=2) +
  geom_vline(aes(xintercept=variability_threshold), colour="red",size=1.5) +
  xlab("Variability of reference samples") + 
  ylab("Cumulative proportion") +
  scale_y_log10() +
  annotate("text", x = 0.025, y=0.5, label = "Threshold = 0.0035", size=8) +
  theme(legend.text=element_text(size=24),legend.title=element_text(size=28),
        axis.title.x = element_text(size=28), axis.title.y = element_text(size=28),
        strip.text.x = element_text(size=24), strip.text.y = element_text(size=24),
        axis.text.x = element_text(size=24), axis.text.y = element_text(size=24))

plot(pp)

#generate table detailing loci and runs/mice with ref distributions with high var
bad.ref = data.ref %>%
            filter(ls_total > variability_threshold) %>%
            select(Loci_full, specific_ID) %>%
            unique()

#remove samples with reference variability higher than threshold from dataset for further analysis
filter.df = data.phi

for (i in 1:nrow(bad.ref)) {
  
  reference = bad.ref[i,]
  filter.df = filter.df %>%
                filter(specific_ID != reference$specific_ID | 
                         loci != reference$Loci_full)
  
  
}

#### separate filtering for distribution plotting
filter.df2 = data.ref

for (i in 1:nrow(bad.ref)) {
  
  reference = bad.ref[i,]
  filter.df2 = filter.df2 %>%
    filter(specific_ID != reference$specific_ID | 
             Loci_full != reference$Loci_full)
  
  
}

#plot a19_4554 dis before filtering
plot.df.before = data.ref %>%
  filter(Loci_full == "a19_4554")

pp.before = ggplot(data=plot.df.before) +
  ggtitle("Locus a19_4554 reference samples before variability thresholding") +
  geom_point(aes(x=Tract_Length,y=propReads, color="Tail Sample"), size=3) +
  geom_point(aes(x=Tract_Length, y=median2, color="Median"), size=3) +
  scale_colour_discrete(name=NULL) +
  xlab("Repeat length") + ylab("Proportion of reads") +
  theme(legend.text=element_text(size=20),legend.title=element_text(size=24), 
        axis.title.x = element_text(size=20), axis.title.y = element_text(size=20),
        strip.text.x = element_text(size=24), strip.text.y = element_text(size=24),
        axis.text.x = element_text(size=10), axis.text.y = element_text(size=18),
        title=element_text(size=20)) +
  facet_grid(. ~ mouse_age)

plot(pp.before)

#plot a4_1365 dis after filtering
plot.df.after = filter.df2 %>%
  filter(Loci_full == "a19_4554")

pp.after = ggplot(data=plot.df.after) +
  ggtitle("Locus a19_4554 reference samples after variability thresholding") +
  geom_point(aes(x=Tract_Length,y=propReads, color="Tail Sample"), size=3) +
  geom_point(aes(x=Tract_Length, y=median2, color="Median"), size=3) +
  scale_colour_discrete(name=NULL) +
  xlab("Repeat length") + ylab("Proportion of reads") +
  theme(legend.text=element_text(size=20),legend.title=element_text(size=24), 
          axis.title.x = element_text(size=20), axis.title.y = element_text(size=20),
          strip.text.x = element_text(size=24), strip.text.y = element_text(size=24),
          axis.text.x = element_text(size=10), axis.text.y = element_text(size=18),
          title=element_text(size=20)) +
  facet_grid(. ~ mouse_age)

plot(pp.after)

#plot supplementary figure 3C
grid.arrange(pp.before, pp.after)

### call PPCs and WPCs
ppc.vector = c()
wpc.vector = c()

for (i in 1:nrow(filter.df)) {
  
  phi.test = filter.df$mean_phi[i]
  loci.test = filter.df$loci[i]
  sex.test = filter.df$sex[i]
  
  # determine threshold for ppc and wpc for this data sample
  ppc.bound =  0.182
  
  # give different threshold for X-linked loci and eyfp locus
  if (loci.test == "sX_1395" & sex.test == "male" | loci.test == "s1_eyfp") {
    
    wpc.bound = 0.596
    
  } else {
    
    wpc.bound = 0.299
    
  }
  
  if (phi.test <= ppc.bound) {
    
    wpc = 0
    ppc = 0
    
  } else if (phi.test < wpc.bound) {
    
    wpc = 0
    ppc = 1
    
  } else {
    
    wpc = 1
    ppc = 0
  }
  
  ppc.vector = c(ppc.vector,ppc)
  wpc.vector = c(wpc.vector,wpc)
  
}

## combined ppc and wpc calls with data.edit
ppc.df = data.frame(ppc.vector)
colnames(ppc.df) = "ppc"

wpc.df = data.frame(wpc.vector)
colnames(wpc.df) = "wpc"

data.cp = cbind(filter.df,ppc.df,wpc.df) 

### calculate total crypts tested within each mouse
### calculate total ppc and wpc within each mouse
crypt_all = unique(data.cp$crypt_ID)

ppc.total = c()
wpc.total = c()
crypt.vector = c()
mouse.vector = c()
age.vector = c()
loci.vector = c()

for (crypt.test in crypt_all) {
  
  crypt.df = data.cp %>%
    filter (crypt_ID == crypt.test)
  
  ppc.sum = sum(crypt.df$ppc)
  wpc.sum = sum(crypt.df$wpc)
  
  crypt.vector = c(crypt.vector,crypt.test)
  mouse.vector = c(mouse.vector,crypt.df$mouse_ID[1])
  age.vector = c(age.vector,crypt.df$mouse_age[1])
  ppc.total = c(ppc.total,ppc.sum)
  wpc.total = c(wpc.total,wpc.sum)
  loci.vector = c(loci.vector,nrow(crypt.df))
  
}

crypt.df = data.frame(crypt.vector)
colnames(crypt.df) = "crypts_ID"
mouse.df = data.frame(mouse.vector)
colnames(mouse.df) = "mouse_ID"
age.df = data.frame(age.vector)
colnames(age.df) = "mouse_age"
ppc.df = data.frame(ppc.total)
colnames(ppc.df) = "total_ppc"
wpc.df = data.frame(wpc.total)
colnames(wpc.df) = "total_wpc"
loci.df = data.frame(loci.vector)
colnames(loci.df) = "N_loci"

crypt.summary = cbind(crypt.df,mouse.df,age.df,ppc.df,wpc.df,loci.df)

crypt.keep = crypt.summary 

crypt.keep = crypt.keep$crypts_ID
crypt.keep = as.character(crypt.keep)

## filter data based on crypt.keep
data.filter = data.cp %>%
  subset(crypt_ID %in% crypt.keep)

### calculate total crypts tested within each mouse
### calculate total ppc and wpc within each mouse
mouse_all = unique(data.filter$mouse_ID)
loci_all = unique(data.filter$loci)

data.final = data.frame()

for (mouse.test in mouse_all) {
  
  mouse.df = data.filter %>%
    filter (mouse_ID == mouse.test)
  
  for (loci.test in loci_all) {
    
    ppc.total = c()
    wpc.total = c()
    crypt.vector = c()
    
    loci.df = mouse.df %>%
      filter (loci == loci.test)
    
    crypt.test = nrow(loci.df)
    ppc.sum = sum(loci.df$ppc)
    wpc.sum = sum(loci.df$wpc)
    
    crypt.vector = c(crypt.vector,rep(crypt.test,crypt.test))
    ppc.total = c(ppc.total,rep(ppc.sum,crypt.test))
    wpc.total = c(wpc.total,rep(wpc.sum,crypt.test))
    
    crypt.df = data.frame(crypt.vector)
    colnames(crypt.df) = "crypts_tested"
    ppc.df = data.frame(ppc.total)
    colnames(ppc.df) = "total_ppc"
    wpc.df = data.frame(wpc.total)
    colnames(wpc.df) = "total_wpc"
    
    final.df = cbind(loci.df,crypt.df,ppc.df,wpc.df)
    
    data.final = rbind(data.final,final.df)
    
  }
  
}

# calculate pct wpc and pct ppc in each sequencing run
data.final = transform(data.final, pct_ppc = total_ppc / crypts_tested *100)
data.final = transform(data.final, pct_wpc = total_wpc / crypts_tested *100)

# create summary data
data.summary = data.final %>%
  select(mouse_age, mouse_ID,loci,crypts_tested,pct_ppc,pct_wpc) %>%
  mutate(mouse_age, mouse_age = as.numeric(as.character(mouse_age))) %>%
  #remove loci with <3 time points
  filter(loci != "a10_2051" & loci != "s15_7506" & loci != "s8_3334" & loci != "s9_6943") %>%
  unique() %>%
  # remove sample with less than 60 crypts analysed
  filter(crypts_tested > 60) 

summary.table = data.summary %>% select(mouse_ID,mouse_age,loci,crypts_tested,pct_ppc,pct_wpc) 

#SUPPLEMENTARY TABLE 5
write.table(summary.table, file="wt_locus_summary.csv", sep=",",row.names=F)

data.summary = ddply(data.final, c("mouse_ID","mouse_age"), summarise,
                     
                     N_total_ppc    = length(total_ppc),
                     pct_ppc = sum(total_ppc) / N_total_ppc * 100,
                     
                     N_total_wpc = length(total_wpc),
                     pct_wpc = sum(total_wpc) / N_total_wpc * 100
                     
)

# plot boxplot
# show number of mutations at each loci
plot.df2 = ddply(data.cp, c("mouse_age","loci"), summarise,
                   
                   total_wpc = sum(wpc),
                   total_ppc = sum(ppc),
                   total_crypts = length(wpc),
                   total_mutants = sum(total_wpc,total_ppc),
                   
                   pct_wpc = total_wpc / total_crypts * 100,
                   pct_ppc = total_ppc / total_crypts * 100,
                   pct_mutants = total_mutants / total_crypts * 100
)

loci.summary = ddply(plot.df2, c("loci"),summarise,
                     
                     N_mice = length(mouse_age)
                     
                ) %>%
              filter(N_mice >= 5)

loci.final = loci.summary$loci

plot.df2 = filter(plot.df2, loci %in% loci.final)

# plot figure 3C
pp2 = plot.df2 %>%
          ggplot(aes(x=loci, y = pct_mutants)) +
          geom_boxplot(size=1) +
          xlab("Locus") + ylab("Mutant crypts (%)") +
          theme(legend.text=element_text(size=24),legend.title=element_text(size=28),
                axis.title.x = element_text(size=28), axis.title.y = element_text(size=28),
                strip.text.x = element_text(size=24), strip.text.y = element_text(size=24),
                axis.text.x = element_text(size=24), axis.text.y = element_text(size=24))

plot(pp2)

# plot as scatter averaged across loci with error bars
data.filter = data.cp

### calculate total crypts tested within each mouse
### calculate total ppc and wpc within each mouse
mouse_all = unique(data.filter$mouse_ID)
loci_all = unique(data.filter$loci)

data.final = data.frame()

for (mouse.test in mouse_all) {
  
  mouse.df = data.filter %>%
    filter (mouse_ID == mouse.test)
  
  for (loci.test in loci_all) {
    
    ppc.total = c()
    wpc.total = c()
    crypt.vector = c()
    
    loci.df = mouse.df %>%
      filter (loci == loci.test)
    
    crypt.test = nrow(loci.df)
    ppc.sum = sum(loci.df$ppc)
    wpc.sum = sum(loci.df$wpc)
    
    crypt.vector = c(crypt.vector,rep(crypt.test,crypt.test))
    ppc.total = c(ppc.total,rep(ppc.sum,crypt.test))
    wpc.total = c(wpc.total,rep(wpc.sum,crypt.test))
    
    crypt.df = data.frame(crypt.vector)
    colnames(crypt.df) = "crypts_tested"
    ppc.df = data.frame(ppc.total)
    colnames(ppc.df) = "total_ppc"
    wpc.df = data.frame(wpc.total)
    colnames(wpc.df) = "total_wpc"
    
    final.df = cbind(loci.df,crypt.df,ppc.df,wpc.df)
    
    data.final = rbind(data.final,final.df)
    
  }
  
}

# calculate pct wpc and pct ppc in each sequencing run
data.final = transform(data.final, pct_ppc = total_ppc / crypts_tested *100)
data.final = transform(data.final, pct_wpc = total_wpc / crypts_tested *100)

# create summary data
data.summary = data.final %>%
  select(mouse_age, mouse_ID,loci,crypts_tested,pct_ppc,pct_wpc) %>%
  mutate(mouse_age, mouse_age = as.numeric(as.character(mouse_age))) %>%
  unique() %>%
  # remove sample with less than 60 crypts analysed
  filter(crypts_tested > 60)

summary.table = data.summary %>% select(mouse_ID,mouse_age,loci,crypts_tested,pct_ppc,pct_wpc)
#write.table(summary.table, file="wt_locus_summary.csv", sep=",",row.names=F)

data.summary = ddply(data.summary, c("mouse_ID","mouse_age"), summarise,
                     N_pct_ppc    = length(pct_ppc),
                     mean_pct_ppc = mean(pct_ppc),
                     sd_pct_ppc   = sd(pct_ppc),
                     se_pct_ppc   = sd_pct_ppc / sqrt(N_pct_ppc),
                     
                     N_pct_wpc    = length(pct_wpc),
                     mean_pct_wpc = mean(pct_wpc),
                     sd_pct_wpc   = sd(pct_wpc),
                     se_pct_wpc   = sd_pct_wpc / sqrt(N_pct_wpc)                                 
                     
)

#write.table(data.summary, file="wt_clone_plot_avg_data.csv", sep=",",row.names=F)

# filter data for plotting
plot.df3 = data.summary

plot.df3[sapply(plot.df3,is.na)] = 0

# plot figure 3D
pp3 = ggplot(data=plot.df3, aes(x=mouse_age, y=mean_pct_ppc,colour="PPC")) +
  geom_point(size=5) +
  geom_errorbar(aes(ymin = mean_pct_ppc - se_pct_ppc, ymax = mean_pct_ppc + se_pct_ppc, colour="PPC"), width=12) +
  geom_smooth(aes(mouse_age,mean_pct_ppc, colour="PPC"), method=lm, se=FALSE, size=2) +
  geom_point(aes(x=mouse_age,y=mean_pct_wpc,colour="WPC"),size=5) +
  geom_errorbar(aes(ymin=mean_pct_wpc-se_pct_wpc, ymax=mean_pct_wpc+se_pct_wpc, colour="WPC"), width=12) +
  geom_smooth(aes(mouse_age,mean_pct_wpc, colour="WPC"), method=lm, se=FALSE,size=2) +
  ylab("Percentage of crypts tested (%)") + xlab("Mouse age (days)") +
  scale_colour_manual(name = 'Clone \naccumulation', values =c('WPC' = '#0072B2','PPC' = '#D55E00')) +
  theme(legend.text=element_text(size=24),legend.title=element_text(size=28),
        axis.title.x = element_text(size=28), axis.title.y = element_text(size=28),
        strip.text.x = element_text(size=24), strip.text.y = element_text(size=24),
        axis.text.x = element_text(size=24), axis.text.y = element_text(size=24))


plot(pp3)