data.msh2 = read.table("data/msh2_data_final.csv",sep=",", header=T, stringsAsFactors=F) %>%
              mutate(type="Msh2")
data.wt = read.table("data/wt_data_final.csv",sep=",", header=T, stringsAsFactors=F) %>%
              mutate(type="WT")

#### WPC in Msh2
plot.df.msh2 = data.msh2 %>%
  mutate(post_induction, post_induction = as.numeric(as.character(post_induction))) %>%
  filter(post_induction != 0 & post_induction != 164) %>%
  filter(crypts_tested > 80) %>%
  select(post_induction, pct_ppc, pct_wpc, loci) %>%
  unique() %>%
  # remove loci with < 3 time points
  filter(loci != "s8_6742")

#### WPC in WT
plot.df.wt = data.wt %>%
  filter(crypts_tested > 80) %>%
  select(mouse_age, pct_ppc, pct_wpc, loci) %>%
  unique() 

### compare WPC accumulation in Msh2 vs WT
pp = ggplot() +
  geom_smooth(data=plot.df.wt, aes(mouse_age,pct_wpc, color = 'Wild-type'), method=lm, se=FALSE, size=2) +
  geom_smooth(data=plot.df.msh2,aes(post_induction,pct_wpc,color='Msh2-deficient'),method=lm, se=FALSE, size=2) +
  scale_colour_discrete(name = 'Mouse') +
  ylab("Percentage of crypts tested (%)") + xlab("Mouse age / time post-induction (days)") +
  theme(legend.text=element_text(size=16),legend.title=element_text(size=22),
        axis.title.x = element_text(size=28), axis.title.y = element_text(size=28),
        strip.text.x = element_text(size=24), strip.text.y = element_text(size=24),
        axis.text.x = element_text(size=24), axis.text.y = element_text(size=24))

plot(pp)
