library(tidyverse)
#https://github.com/MorrisseyLab/CryptDriftR
library(CryptDriftR)
library(foreach)
library(doMC)
registerDoMC(16)

data_all = bind_rows(read_csv("msh2_locus_summary.csv") %>% mutate(geno_type = "msh2"),
                     read_csv("wt_locus_summary.csv") %>% mutate(geno_type = "wt", post_induction = mouse_age)) %>% 
  mutate(count_partial = round(crypts_tested*pct_ppc/100,0), count_monoclonal = round(crypts_tested*pct_wpc/100,0))

msh2_data = data_all %>% filter(geno_type == "msh2") 

my_quant = function(x_vec, quant) which(x_vec>quant)[1] %>% ifelse(is.na(.), length(x_vec), .)

find_quantiles = function(df){
  x_vec       = df$post
  alpha_vals  = df$alpha
  rel_sizes   = cumsum(x_vec)
  indx_use = my_quant(rel_sizes, 0.025)
  p1 = alpha_vals[indx_use]
  indx_use = my_quant(rel_sizes, 0.25)
  p2 = alpha_vals[indx_use]
  indx_use = my_quant(rel_sizes, 0.5)
  pmid= alpha_vals[indx_use]
  indx_use = my_quant(rel_sizes, 0.75)
  p3 = alpha_vals[indx_use]
  indx_use = my_quant(rel_sizes, 0.975)
  p4 = alpha_vals[indx_use]
  tibble(`2.5%` = p1, `25%` = p2, `50%` = pmid, `75%` = p3, `97.5%` = p4)
}

## Assume most noise comes from sampling variability
log_likelihood_monoclonal <- function(alpha, lambda, N, time_vec, monoclonal_crypts, total_crypts, num_sims = 1e5, sd_half_normal = 5e-2){
  ## Hack to get around only one timepoint gievn, concatenate t = 0       time_points = c(0, time_vec)
  prob_cont_lab = sim_contLabelling(mu = alpha, lambda = lambda, Ns = N, time_points = c(0, time_vec), numSim = 1e5)[2,] 
  prob_cont_lab = prob_cont_lab[-1] # Remove added 0
  ## Using half-normal as prior
  dbinom(monoclonal_crypts, total_crypts, prob_cont_lab, log = T) %>% sum(.) - alpha^2/(2*sd_half_normal)
}

posterior_alpha <- function(alpha_range, lambda, N, time_vec, monoclonal_crypts, total_crypts, num_sims = 1e5){
  tibble(alpha = alpha_range) %>% 
    group_by(alpha) %>% 
    mutate(log_lik = log_likelihood_monoclonal(alpha, lambda, N, time_vec, monoclonal_crypts, total_crypts, num_sims)) %>% 
    ungroup() %>% 
    mutate(lik = exp(log_lik-max(log_lik)), post = lik/sum(lik))
}

## Run in parallel
msh2_loci =  unique(msh2_data$loci)
alpha_vals = seq(1e-3, 50e-3, length.out = 200)
all_runs_msh2 = foreach(loci_name_i = msh2_loci)%dopar%{
  loci_i = msh2_data %>% filter(loci == loci_name_i) %>% arrange(post_induction)
  posterior_alpha(alpha_vals, 0.3, 7, loci_i$post_induction, loci_i$count_monoclonal, loci_i$crypts_tested) %>% mutate(loci = loci_name_i)
}

#supplementary table 7
msh2_inf_sumry = all_runs_msh2 %>% bind_rows() %>% group_by(loci) %>% do(find_quantiles(.))

#figure 3H
msh2_inf_sumry %>% 
  ggplot(aes(x = loci, y = `50%`, col = loci)) + geom_point() + geom_errorbar(aes(ymin = `2.5%`, ymax = `97.5%`), width = 0.1) + 
  ylab("alpha") + theme(legend.position="none",  axis.text.x=element_text(angle=45,hjust=1))

