library(dplyr)
library(tidyr)
library(stringr)
library(ggplot2)
library(reshape2)
library(plyr)

data.wt = read.table("data/wt_phi_data.csv", sep=",", header=T,stringsAsFactors=F)  %>%
            filter(slxID != "SLX9309" & slxID != "SLX9311")  %>%
            mutate(phenotype = "Wild-type")

data.msh2 = read.table("data/msh2_phi_data.csv", sep=",", header=T,stringsAsFactors=F)  %>%
            mutate(phenotype = "Msh2 deficient")

data.raw = rbind(data.wt,data.msh2)

### call PPCs and WPCs
ppc.vector = c()
wpc.vector = c()

for (i in 1:nrow(data.raw)) {
  
  phi.test = data.raw$mean_phi[i]
  
  ppc.bound = 0.182
  wpc.bound = 0.596
  wpc.bound = 0.299
  
  if (phi.test <= ppc.bound) {
    
    wpc = 0
    ppc = 0
    
  } else if (phi.test < wpc.bound) {
    
    wpc = 0
    ppc = 1
    
  } else {
    
    wpc = 1
    ppc = 0
  }
  
  ppc.vector = c(ppc.vector,ppc)
  wpc.vector = c(wpc.vector,wpc)
  
}

## combined ppc and wpc calls with data.edit
ppc.df = data.frame(ppc.vector)
colnames(ppc.df) = "ppc"

wpc.df = data.frame(wpc.vector)
colnames(wpc.df) = "wpc"

data.cp = cbind(data.raw,ppc.df,wpc.df)

plot.df = data.cp %>%
          #remove transgenic locus
          filter(loci != "s1_eyfp") %>%
          # remove loci with signicant differences in germline between WT and Msh2 mice
          filter(loci != "a10_2051" & loci != "sX_1395") %>%
          filter(shift < -0.6 | shift > 0.6)

#figure 3I
pp = ggplot(plot.df, aes(x=shift, fill=phenotype)) +
    geom_histogram(aes(y=..density..), binwidth=1, position="identity",alpha=0.5) +
    xlab("Shift relative to wild-type") + ylab("Proportion of crypts") +
    theme(legend.text=element_text(size=24),legend.title=element_text(size=28),
        axis.title.x = element_text(size=28), axis.title.y = element_text(size=28),
        strip.text.x = element_text(size=24), strip.text.y = element_text(size=24),
        axis.text.x = element_text(size=24), axis.text.y = element_text(size=24), 
        panel.margin = unit(7, "mm")) +
    scale_fill_discrete(name = "Phenotype")
  
plot(pp)

#supplementary figure 3E
pp2 = ggplot(plot.df, aes(x=shift, fill=phenotype)) +
  geom_histogram(aes(y=..density..), binwidth=1, position="identity",alpha=0.5) +
  facet_wrap(~ loci, nrow=3) +
  xlab("Shift relative to wild-type") + ylab("Proportion of crypts") +
  theme(legend.text=element_text(size=24),legend.title=element_text(size=28),
        axis.title.x = element_text(size=28), axis.title.y = element_text(size=28),
        strip.text.x = element_text(size=24), strip.text.y = element_text(size=24),
        axis.text.x = element_text(size=24), axis.text.y = element_text(size=24), 
        panel.margin = unit(7, "mm")) +
  scale_fill_discrete(name = "Phenotype")

plot(pp2)
