library(dplyr)
library(tidyr)
library(stringr)
library(ggplot2)
# user defined variables
read_number<-1000
microsatellite_min = 20
microsatellite_max = 40

# merge
data.raw = read.table("data/slx7544_optimisation_experiments1.csv",header=T,sep=",",stringsAsFactors = F,row=1)

#re-format
data.edit = data.frame(t(data.raw)) 
sample.names = row.names(data.edit)
data.edit = cbind(data.edit,sample.names)

data.final = data.edit %>%
  separate(sample.names, into = c("chrom", "num", "direction", "Dinuc","Dinuc2"), sep = "_") %>%
  separate(sample_name, into = c("mc", "enzyme", "dna_input", "bc_pcr_cycles","anneal_temp","primer"), sep = "_") %>%
  gather(Tract_Length, NumReads, 1:51) %>%
  mutate(NumReads, NumReads = as.numeric(NumReads)) %>%
  mutate(Tract_Length = str_replace(Tract_Length, "X", "")) %>%
  mutate(Tract_Length = as.numeric(Tract_Length)) %>%
  mutate(sample_number = as.numeric(as.character(sample_number))) %>%
  mutate(s2nmean = as.numeric(as.character(s2nmean))) %>%
  mutate(mode = as.numeric(as.character(mode))) %>%
  filter(Tract_Length >= microsatellite_min, Tract_Length <= microsatellite_max) %>%
  mutate(primer = paste(chrom,num,sep="_"))    %>%
  within(dist_reads<-ave(NumReads, sample_number, direction, primer, FUN=sum)) %>%
  select(total_reads, sample_number, enzyme, dna_input, bc_pcr_cycles, anneal_temp, primer,Tract_Length, NumReads,dist_reads,s2nmean)

### calculare proportional read values
data.final = transform(data.final, propReads = NumReads / dist_reads)

is.nan.data.frame <- function(x)
  do.call(cbind, lapply(x, is.nan))

data.final[is.nan(data.final)] <- 0

### filter data for plotting
plot.df = filter(data.final, dna_input == "10ng" & enzyme == "PHU")

### plot all data
pp = ggplot(plot.df, aes(x=dist_reads,y=s2nmean,color = as.character(primer))) + 
  geom_point(alpha=0.8, size=3) +
  ylim(0,70) +
  scale_x_log10(limits=c(0.1,1000000)) +
  xlab("Total reads between [CA]20 and [CA]35") + ylab("Number of reads at distribution peak + 1[CA] \n / Number of reads at distribution peak") +
  theme(legend.text=element_text(size=16),legend.title=element_text(size=20),
        axis.title.x = element_text(size=20), axis.title.y = element_text(size=20,vjust=0.5),
        strip.text.x = element_text(size=14), strip.text.y = element_text(size=14),
        axis.text.x = element_text(size=18), axis.text.y = element_text(size=18)) +
  scale_color_discrete(name = "Loci") +
  geom_vline(xintercept = read_number)
plot(pp)

### plot over 1000 reads
plot.df2 = plot.df %>%
            filter(dist_reads > read_number)

pp2 = ggplot(plot.df2, aes(x=dist_reads,y=s2nmean,color = as.character(primer))) + 
  geom_point(alpha=0.8, size=3) +
  ylim(0,70) +
  scale_x_log10(limits=c(0.1,1000000)) +
  xlab("Total reads between [CA]20 and [CA]35") + ylab("Number of reads at distribution peak + 1[CA] \n / Number of reads at distribution peak") +
  theme(legend.text=element_text(size=16),legend.title=element_text(size=20),
        axis.title.x = element_text(size=20), axis.title.y = element_text(size=20,vjust=0.5),
        strip.text.x = element_text(size=14), strip.text.y = element_text(size=14),
        axis.text.x = element_text(size=18), axis.text.y = element_text(size=18)) +
  scale_color_discrete(name = "Loci") +
  geom_vline(xintercept = read_number)
plot(pp2)


