library(dplyr)
library(tidyr)
library(stringr)
library(ggplot2)
# user defined variables
read_number<-1000
microsatellite_min = 20
microsatellite_max = 40

# read in data
data.raw = read.table("data/slx7544_optimisation_experiments1.csv",header=T,sep=",",stringsAsFactors = F,row=1)

#re-format
data.edit = data.frame(t(data.raw)) 
sample.names = row.names(data.edit)
data.edit = cbind(data.edit,sample.names)

data.final = data.edit %>%
  separate(sample.names, into = c("strand","sample","direction", "Dinuc","Dinuc2"), sep = "_") %>%
  separate(sample_name, into = c("CA","enzyme","dna_input", "bc_pcr_cycles","anneal_temp","primer"), sep = "_") %>%
  mutate(primer = paste(strand,sample,sep="_")) %>%
  gather(Tract_Length, NumReads, 1:51) %>%
  mutate(NumReads, NumReads = as.numeric(NumReads)) %>%
  mutate(Tract_Length = str_replace(Tract_Length, "X", "")) %>%
  mutate(Tract_Length = as.numeric(Tract_Length)) %>%
  mutate(sample_number = as.numeric(as.character(sample_number))) %>%
  filter(Tract_Length >= microsatellite_min, Tract_Length <= microsatellite_max) %>%
  within(dist_reads<-ave(NumReads, sample_number, direction, primer, FUN=sum)) %>%
  select(total_reads, sample_number, enzyme, dna_input, bc_pcr_cycles, anneal_temp, primer, direction,Tract_Length, NumReads,dist_reads)

### calculare proportional read values
data.final = transform(data.final, propReads = NumReads / dist_reads)

is.nan.data.frame <- function(x)
  do.call(cbind, lapply(x, is.nan))

data.final[is.nan(data.final)] <- 0

### filter data for plotting
plot.df = filter(data.final, dna_input == "10ng" & bc_pcr_cycles == "15cycles" & enzyme == "PHU" & dist_reads > 1000)

### plot
pp = ggplot(plot.df, aes(x=Tract_Length,y=propReads,color = as.character(anneal_temp))) + 
  geom_point(alpha=1, size=5) +
  geom_line(alpha=1, size=2) +
  facet_grid( ~ primer) +
  xlab("Repeat length") + ylab("Proportion of reads") +
  theme(legend.text=element_text(size=24),legend.title=element_text(size=28),
        axis.title.x = element_text(size=28), axis.title.y = element_text(size=28),
        strip.text.x = element_text(size=24), strip.text.y = element_text(size=24),
        axis.text.x = element_text(size=24), axis.text.y = element_text(size=24)) +
  scale_color_discrete(name = "Annealing\ntemperature",labels = c(expression(paste("66.2",degree,"C")), expression(paste("67.9",degree,"C")),
                                                       expression(paste("69.2",degree,"C")),expression(paste("70.1",degree,"C")),expression(paste("70.8",degree,"C")),
                                                      expression(paste("71.0",degree,"C"))))
plot(pp)